using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class FoafTester : System.Web.UI.Page
{
	protected void Page_Load(object sender, EventArgs e)
	{
		btnParse.Click += new EventHandler(btnParse_Click);
		repFriends.ItemDataBound += new RepeaterItemEventHandler(repFriends_ItemDataBound);
	}

	void repFriends_ItemDataBound(object sender, RepeaterItemEventArgs e)
	{
		Person person = (Person)e.Item.DataItem;
		Image img = (Image)e.Item.FindControl("imgPhoto");
		Label name = (Label)e.Item.FindControl("lblName");
		Label foaf = (Label)e.Item.FindControl("lblFoaf");

		name.Text = person.Gender ?? person.NickName;
		foaf.Text = "<b>FOAF address:</B> " + person.FoafLocation;
		if (person.Photo != null)
		{
			img.ImageUrl = person.Photo;
		}
	}

	void btnParse_Click(object sender, EventArgs e)
	{
		FoafParser parser = new FoafParser();
		parser.Parse(new Uri(txtUrl.Text));

		if (parser.IsParsed)
		{
			ltOwner.Text = parser.Owner.Name ?? parser.Owner.NickName;
			repFriends.DataSource = parser.Friends;
			repFriends.DataBind();
		}
		else
		{
			ltOwner.Text = "No supported FOAF document found on that location";
		}
	}

	#region Async example

	private void RetrieveAsync()
	{
		FoafParser parser = new FoafParser();
		parser.Parse(new Uri(txtUrl.Text));

		if (parser.IsParsed)
		{
			parser.FriendParsingComplete += new EventHandler<EventArgs>(parser_FriendParsingComplete);
			parser.ParseFriendsAsync();
		}
	}

	void parser_FriendParsingComplete(object sender, EventArgs e)
	{
		// Now the Friends collection has been updated asynchronously.
		FoafParser parser = (FoafParser)sender;
		Response.Write(parser.Friends.Count);
	}

	#endregion

}
